@@ -4,6 +4,7 @@ from contextlib import contextmanager
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional, Sequence, Tuple, Union
 
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 from appdirs import user_config_dir
 
@@ -327,3 +328,25 @@ def subplots(
     )
 
     return plt.subplots(nrows, ncols, figsize=_figsize, **kwargs)
+
+
+def delete_styles_from_previous_installation() -> None:
+    """A helper function to remove old style files."""
+    old = [
+        "latex10pt-minimal.mplstyle",
+        "latex10pt.mplstyle",
+        "latex11pt-minimal.mplstyle",
+        "latex11pt.mplstyle",
+        "latex12pt-minimal.mplstyle",
+        "latex12pt.mplstyle",
+        "latex9pt-minimal.mplstyle",
+        "latex9pt.mplstyle",
+    ]
+
+    styledir = Path(mpl.get_configdir()) / "stylelib"
+
+    for name in old:
+        style = styledir / name
+
+        if style.exists() and input(f"delete {style}? [y/N]") == "y":
+            style.unlink()
